stat class

Inheritance
Implemented types
Available extensions

Constructors

stat()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
st_atim ↔ timespec
getter/setter pair
st_blksize ↔ int
getter/setter pair
st_blocks ↔ int
getter/setter pair
st_ctim ↔ timespec
getter/setter pair
st_dev ↔ int
getter/setter pair
st_gid ↔ int
getter/setter pair
st_ino ↔ int
getter/setter pair
st_mode ↔ int
getter/setter pair
st_mtim ↔ timespec
getter/setter pair
getter/setter pair
st_rdev ↔ int
getter/setter pair
st_size ↔ int
getter/setter pair
st_uid ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited