tm class

Inheritance
Implemented types
Available extensions

Constructors

tm()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tm_gmtoff ↔ int
getter/setter pair
tm_hour ↔ int
getter/setter pair
tm_isdst ↔ int
getter/setter pair
tm_mday ↔ int
getter/setter pair
tm_min ↔ int
getter/setter pair
tm_mon ↔ int
getter/setter pair
tm_sec ↔ int
getter/setter pair
tm_wday ↔ int
getter/setter pair
tm_yday ↔ int
getter/setter pair
tm_year ↔ int
getter/setter pair
tm_zone ↔ Pointer<Int8>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited